ete2.clustering.clustertree

Package ete2 :: Package clustering :: Module clustertree |
[hide private]
[frames] | no frames]

# Module clustertree

source code

Classes | [hide private]
| ClusterNode Creates a new Cluster Tree object, which is a collection of ClusterNode instances connected in a hierarchical way, and representing a clustering result.
| ClusterTree Creates a new Cluster Tree object, which is a collection of ClusterNode instances connected in a hierarchical way, and representing a clustering result.

Variables | [hide private]
| __VERSION__ = ``'``ete2-2.0rev90``'``
| __package__ = ``'``ete2.clustering``'``